package com.ruoyi.web.controller.board;

import com.ruoyi.board.domain.AlertPlan;
import com.ruoyi.board.domain.dto.AlertPlanAndPlanTypeDTO;
import com.ruoyi.board.service.IAlertPlanService;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 预警计划Controller
 *
 * @author fuhao
 * @Date 2024-08-06
 */
@RestController
@RequestMapping("/board/plan")
public class AlertPlanController extends BaseController {
    @Autowired
    private IAlertPlanService alertPlanService;

    /**
     * 查询预警计划列表
     */
    @PreAuthorize("@ss.hasPermi('alert:plan:list')")
    @GetMapping("/list")
    public TableDataInfo list(AlertPlan alertPlan) {
        startPage();
        List<AlertPlanAndPlanTypeDTO> list = alertPlanService.listPage(alertPlan);
        return getDataTable(list);
    }

    /**
     * 导出预警计划列表
     */
    @PreAuthorize("@ss.hasPermi('alert:plan:export')")
    @Log(title = "预警计划", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, AlertPlan alertPlan) {
        List<AlertPlan> list = alertPlanService.list();
        ExcelUtil<AlertPlan> util = new ExcelUtil<AlertPlan>(AlertPlan.class);
        util.exportExcel(response, list, "预警计划数据");
    }

    /**
     * 获取预警计划详细信息
     */
    @PreAuthorize("@ss.hasPermi('alert:plan:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(alertPlanService.getDTOById(id));
    }

    /**
     * 新增预警计划
     */
    @PreAuthorize("@ss.hasPermi('alert:plan:add')")
    @Log(title = "预警计划", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody AlertPlan alertPlan) {
        return toAjax(alertPlanService.save(alertPlan));
    }

    /**
     * 修改预警计划
     */
    @PreAuthorize("@ss.hasPermi('alert:plan:edit')")
    @Log(title = "预警计划", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody AlertPlan alertPlan) {
        return toAjax(alertPlanService.saveOrUpdate(alertPlan));
    }

    /**
     * 删除预警计划
     */
    @PreAuthorize("@ss.hasPermi('alert:plan:remove')")
    @Log(title = "预警计划", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable List<Long> ids) {
        return toAjax(alertPlanService.removeByIds(ids));
    }
}